## Citation: This lecture is heavily based off the tutorial from shiny.rstudio.com
## and can be found in Lesson 5 of the tutorial.

# server.R
## Loading in libraries (think of ggplot2)
library(maps)
library(mapproj)
counties <- readRDS("data/counties.rds")
## Helper script for percent_map
source("helpers.R")

shinyServer(
  function(input, output) {
    ## Take data from input, filter out necessary data,
    ## find color, and plot using percent_map
    output$map <- renderPlot({
      data <- switch(input$var, 
                     "Percent White" = counties$white,
                     "Percent Black" = counties$black,
                     "Percent Hispanic" = counties$hispanic,
                     "Percent Asian" = counties$asian)
      
      color <- switch(input$var, 
                      "Percent White" = "darkgreen",
                      "Percent Black" = "black",
                      "Percent Hispanic" = "darkorange",
                      "Percent Asian" = "darkviolet")
      
      legend <- switch(input$var, 
                       "Percent White" = "% White",
                       "Percent Black" = "% Black",
                       "Percent Hispanic" = "% Hispanic",
                       "Percent Asian" = "% Asian")
      
      ## defined in helpers.R
      percent_map(var = data, 
                  color = color, 
                  legend.title = legend, 
                  max = input$range[2], 
                  min = input$range[1])
    })
  }
)