## Citation: This lecture is heavily based off the tutorial from shiny.rstudio.com
## and can be found in Lesson 5 of the tutorial.

# ui.R
shinyUI(fluidPage(
  ## Sets Title of Application
  titlePanel("censusVis"),
  
  ## Sidebar layout with a sidebar panel and a main panel
  ## Can adjust using HTML, organize by order, etc
  sidebarLayout(
    ## Note that we define variables such as var and range
    sidebarPanel(
      ## Text of Panel
      helpText("Create demographic maps with 
               information from the 2010 US Census."),
      
      ## Input selector
      selectInput("var", 
                  label = "Choose a variable to display",
                  choices = c("Percent White", "Percent Black",
                              "Percent Hispanic", "Percent Asian"),
                  selected = "Percent White"),
      
      ## Slider input selector
      sliderInput("range", 
                  label = "Range of interest:",
                  min = 0, max = 100, value = c(0, 100))
      ),
    
    ## Display our final plot, note that we reference to it as "map"
    mainPanel(plotOutput("map"))
  )
))

## UI Output: 
##   Output            creates
## htmlOutput         raw HTML
## imageOutput         image
## plotOutput	         plot
## tableOutput	       table
## textOutput	         text
## uiOutput	          raw HTML
## verbatimTextOutput	  text

## More information on UI and reference in general:
## http://shiny.rstudio.com/reference/shiny/latest/
